@@ -2,15 +2,10 @@
 #include "pyspotify.h"
 
 typedef struct {
-    PyObject_HEAD sp_playlistcontainer *_playlistcontainer;
+    PyObject_HEAD
+    sp_playlistcontainer *_playlistcontainer;
 } PlaylistContainer;
 
-extern PyTypeObject PlaylistContainerType;
-
-extern void playlistcontainer_init(PyObject *m);
-
-PyObject *PlaylistContainer_FromSpotify(sp_playlistcontainer * container);
-
 /* Keep track of callbacks added to a playlist container */
 typedef struct _playlistcontainer_callback {
     sp_playlistcontainer_callbacks *callback;
@@ -24,3 +19,14 @@ typedef struct _plc_cb_entry {
     playlistcontainer_callback *callbacks;
     struct _plc_cb_entry *next;
 } plc_cb_entry;
+
+#define PlaylistContainer_SP_PLAYLISTCONTAINER(o) \
+    ((PlaylistContainer *)o)->_playlistcontainer
+
+extern PyTypeObject PlaylistContainerType;
+
+PyObject *
+PlaylistContainer_FromSpotify(sp_playlistcontainer *container, bool add_ref);
+
+extern void
+playlistcontainer_init(PyObject *module);
